# -*- coding: UTF-8 -*-
'''
@Author  ：程序员晚枫，B站/抖音/微博/小红书/公众号
@WeChat     ：CoderWanFeng
@Blog      ：www.python-office.com
@Date    ：2023/1/22 18:45 
@Description     ：加载配置信息，core中类的父类
'''
import toml
from poocr.lib.Const import DEFAULT_CONFIG_PATH_NAME, DEFAULT_CONFIG_NAME, TUTORIA_VIDEO


class poocrConfig():
    def __init__(self):
        self.config_info = None

    def get_config(self, configPath):
        """
        解析配置文件
        :param toml_path: 存放配置文件的位置和名称，在py文件的同级路径下
        :return: 加载后的信息
        """
        try:
            if configPath == None:
                self.config_info = toml.load(DEFAULT_CONFIG_PATH_NAME)
            else:
                self.config_info = toml.load(configPath)
            print(f'配置文件【{DEFAULT_CONFIG_NAME}】读取成功')
            return self.config_info
        except:
            print(f'配置文件【{DEFAULT_CONFIG_NAME}】读取失败，请查看视频，进行配置：{TUTORIA_VIDEO}')



import unittest

from poocr.api.ocr import *
from poocr.api.ocr2excel import *


class TestTencent(unittest.TestCase):

    def test_vin_ocr(self):
        r = VatInvoiceOCR(img_path=r'C:\Users\Lenovo\Desktop\temp\增值税发票-test.jpg')
        print(r)

    def test_idcard_ocr(self):
        res = IDCardOCR(
            img_path=r'C:\Users\Lenovo\Desktop\temp\正面.jpg')
        print(res)

    def test_VatInvoiceOCR2Excel(self):
        VatInvoiceOCR2Excel(intput_path=r'C:\Users\Lenovo\Desktop\temp\Snipaste_2023-04-09_22-23-48.png',
                            output_excel=r'./VatInvoiceOCR2Excel.xlsx',
                            configPath=r'./poocr-config.toml')
    def test_TrainTicketOCR2Excel(self):
        TrainTicketOCR2Excel(input_path='', output_excel='',configPath='fdasf')


# -*- coding: UTF-8 -*-
'''
@Author  ：程序员晚枫，B站/抖音/微博/小红书/公众号
@WeChat     ：CoderWanFeng
@Blog      ：www.python-office.com
@Date    ：2023/1/22 15:21 
@Description     ：
'''
from . import ocr
from . import ocr2excel


from poocr.api import ocr
from poocr.api import ocr2excel
from poocr.lib.Const import SPLIT_LINE

print(SPLIT_LINE)
print('【poocr库】，功能持续更新中')
print('使用有问题 or 提交你的功能需求 or 参与项目开发')
print('1、全部功能【视频 & 文字】教程：https://mp.weixin.qq.com/s/WxICBZZSgkm-OrvXB82hbg')
print('2、请+【项目交流群】：http://t.cn/A65MiFvH')
print('3、本开源项目的【代码仓库】：https://github.com/CoderWanFeng/poocr')
print(SPLIT_LINE)


# -*- coding: UTF-8 -*-
'''
@Author  ：B站/抖音/微博/小红书/公众号，都叫：程序员晚枫
@WeChat     ：CoderWanFeng
@Blog      ：www.python-office.com
@Date    ：2023/3/25 18:53 
@Description     ：
'''
import json
from pathlib import Path

import pandas as pd
from pofile import get_files, mkdir
from poprogress import simple_progress

import poocr
from poocr.api.ocr import VatInvoiceOCR


def VatInvoiceOCR2Excel(input_path, output_path=None, output_excel='VatInvoiceOCR2Excel.xlsx', img_url=None,
                        configPath=None):
    """
    批量识别发票，并保存在Excel中
    :param input_path: 发票存放位置，可以填单个文件，也可以填一个目录
    :param output_path:
    :param output_excel:
    :param img_url:
    :param configPath:
    :return:
    """
    vat_img_files = get_files(input_path)
    abs_intput_path = Path(input_path).absolute()
    if output_path == None:
        output_path = './'
    mkdir(Path(output_path).absolute())  # 如果不存在，则创建输出目录
    if output_excel.endswith('.xlsx') or output_excel.endswith('xls'):  # 如果指定的输出excel结尾不正确，则报错退出
        abs_output_excel = Path(output_path).absolute() / output_excel
    else:  # 指定了，但不是xlsx或者xls结束
        raise BaseException(
            f'输出结果名：output_excel参数，必须以xls或者xlsx结尾，您的输入:{output_excel}有误，请修改后重新运行')
    res_df = []  # 装全部识别的结果
    for vat_img in simple_progress(vat_img_files):
        try:
            api_res = VatInvoiceOCR(img_path=str(vat_img), img_url=img_url, configPath=configPath)
        except:
            continue
        api_res_json = json.loads(str(api_res))
        VatInvoiceInfos = api_res_json['VatInvoiceInfos']
        dict_pandas = {}  # 存放一行数据
        # 读返回值的第一个key
        for VatInvoiceInfo in VatInvoiceInfos:
            dict_pandas[VatInvoiceInfo['Name']] = VatInvoiceInfo['Value']
        # 读返回值的第二个key
        Items = api_res_json['Items']
        for Item in Items:
            dict_pandas.update(Item)
            res_df.append(pd.DataFrame(dict_pandas, index=[0]))
    # 整理全部识别结果
    res_excel = res_df[0]
    for index, line_df in enumerate(res_df):
        if index == 0:
            continue
        res_excel = res_excel._append(line_df)
    pd.DataFrame(res_excel).to_excel(str(abs_output_excel))  # 写入Excel


def TrainTicketOCR2Excel(input_path: str, output_excel: str = r'./TrainTicketOCR2Excel.xlsx', img_url: str = None,
                         configPath: str = None) -> None:
    ticket_list = []
    ticket_files = get_files(input_path)
    for ticket in simple_progress(ticket_files):
        ticket_info = poocr.ocr.TrainTicketOCR(img_path=ticket, img_url=img_url, configPath=configPath)
        ticket_list.append(ticket_info)
    ticket_df = pd.DataFrame(ticket_list)
    ticket_df.to_excel(output_excel, index=None)
